| AddSickleJrMetadata | R Documentation |
Add any type of metadata to an object of class SickleJr. Metadata
are stored in list format under the name specified in metadataname of each node in slot metadata.
AddSickleJrMetadata(SickleJr, metadata, metadataname)
SickleJr |
An object of class SickleJr holding at least one count matrix of omics data |
metadata |
Metadata to add to the SickleJr object; there are no restrictions on type |
metadataname |
A string input that indicates the desired name for the added metadata. |
An object of class SickleJr with added metadata
SimSickleJrSmall<-AddSickleJrMetadata(SimSickleJrSmall,
SimData$cell_type,"cell_types_full_data")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.