BuildSNNGraphLaplacians: Build SNN graphs and generate their graph Laplacians
Description
Generate graph Laplacians for graph regularization of
jrSiCKLSNMF from the list of raw count matrices using an SNN graph. SNN is more robust to
situations where the number of cells outnumbers the number of features. Uses
the scran package's BuildSNNGraph function Lun2016jrSiCKLSNMF
Usage
BuildSNNGraphLaplacians(SickleJr, k = 20)
Value
An object of class SickleJr with list of graph Laplacians in sparse
matrix format added to its graph.laplacian.list slot
Arguments
SickleJr
An object of class SickleJr
k
Number of KNN neighbors to calculate SNN graph; defaults to 20