Learn R Programming

jrSiCKLSNMF (version 1.2.3)

CalculateUMAPSickleJr: Calculate the UMAP for an object of class SickleJr

Description

Perform UMAP on the \(\mathbf{H}\) matrix alone (default) or within a modality by using UMAP on the \(W^vH\) corresponding to modality \(v\).

Usage

CalculateUMAPSickleJr(
  SickleJr,
  umap.settings = umap::umap.defaults,
  modality = NULL
)

Value

An object of class SickleJr with UMAP output based on the \(\mathbf{H}\) matrix alone or within a modality added to its umap slot

Arguments

SickleJr

An object of class SickleJr

umap.settings

Optional settings for the umap; defaults to umap.defaults

modality

A number corresponding to the desired modality; if set, will perform UMAP on \(\mathbf{W}^{\mathtt{modality}}\) on \(\mathbf{H}\) alone; not recommended for datasets of more than 1000 cells

References

UMAPjrSiCKLSNMF

Examples

Run this code
#Since this example has only 10 observations,
#we need to modify the number of neighbors from the default of 15
umap.settings=umap::umap.defaults
umap.settings$n_neighbors=2
SimSickleJrSmall<-CalculateUMAPSickleJr(SimSickleJrSmall,
umap.settings=umap.settings)
SimSickleJrSmall<-CalculateUMAPSickleJr(SimSickleJrSmall,
umap.settings=umap.settings,modality=1)
SimSickleJrSmall<-CalculateUMAPSickleJr(SimSickleJrSmall,
umap.settings=umap.settings,modality=2)

Run the code above in your browser using DataLab