DetermineDFromIRLBA: Create elbow plots of the singular values derived from IRLBA
to determine D for large datasets
Description
This generates v+1 plots, where v is the number of data modalities, of the approximate
singular values generated by IRLBA.There is one plot for each modality and then a
final plot that concatenates all of the modalities together. Choose the largest elbow
value among the three plots.
Usage
DetermineDFromIRLBA(SickleJr, d = 50)
Value
An object of class SickleJr with plots for IRLBA diagnostics added to its plots slot
Arguments
SickleJr
An object of class SickleJr
d
Number of desired factors; it is important to select a number that
allows you to see a clear elbow: defaults to 50.