- SickleJr
An object of class SickleJr
- rounds
Number of rounds to use: defaults to 100; this process is time consuming,
so a high number of rounds is not recommended
- differr
Tolerance for the percentage update in the likelihood: for these plots,
this defaults to \(1e-4\)
- d_vector
Vector of \(d\) values to test: default is 2 to 20
- parallel
Boolean indicating whether to use parallel computation
- nCores
Number of desired cores; defaults to the number of cores of the current machine minus 1 for convenience
- subsampsize
Size of the random subsample (defaults to NULL, which means all cells will be used); using a random subsample decreases computation time but sacrifices accuracy
- minibatch
Boolean indicating whether to use the mini-batch algorithm: default is FALSE
- random
Boolean indicating whether to use random initialization to generate the \(\mathbf{W}^v\) matrices and \(\mathbf{H}\) matrix:
defaults to FALSE
- random_W_updates
Boolean parameter for mini-batch algorithm; if TRUE, only updates \(\mathbf{W}^v\) once per epoch on the
penultimate subset of \(\mathbf{H}\); otherwise updates \(\mathbf{W}^v\) after every update of the subset of \(\mathbf{H}\)
- seed
Number representing the random seed
- batchsize
Desired batch size; do not use if using a subsample
- lossonsubset
Boolean indicating whether to calculate the loss on a subset rather than the full dataset; speeds up computation for larger datasets
- losssubsetsize
Number of cells to use for the loss subset; default is total number of cells