Defines the SickleJr class for use with jrSiCKLSNMF. This object contains all of the information required for analysis using jrSiCKLSNMF. This includes count matrices, normalized matrices, graph Laplacians, hyperparameters, diagnostic plots, and plots of cell clusters.
An object of class SickleJr
count.matricesA list containing all of the quality controlled count matrices. Note that these count matrices should not use all features and should only include features that appear in at a minimum 10 cells.
normalized.count.matricesA list that holds the normalized count matrices
graph.laplacian.listA list of the graph Laplacians to be used for graph regularization
rowRegularizationA string that indicates the type of row regularization to use. Types include "None" and "L2Norm"
diffFuncA string that holds the name of the function used to measure the discrepancy between
data matrix X and WH for each modality; can be "klp" for the Poisson Kullback-Leibler divergence
or "fr" for the Frobenius norm
lambdaWlistA list of lambda values to use as the hyperparameters for the corresponding \(\mathbf{W}^v\) in the \(v^{\text{th}}\) modality
lambdaHA numeric value corresponding to the hyperparameter of the sparsity constraint on \(\mathbf{H}\)
WlistA list of the generated \(\mathbf{W}^v\) matrices, one for each modality
HThe shared \(\mathbf{H}\) matrix
WHinitialsA list that if, when using PlotLossvsLatentFactors, all of the cells are used to calculate
the initial values, stores these initial generated matrices; can be used
as initializations when running RunjrSiCKLSNMF to save time
lossCalcSubsampleA vector that holds the cell indices on which PlotLossvsLatentFactors was calculated
latent.factor.elbow.valuesA data frame that holds the relevant information to plot the latent factor elbow plot
minibatchIndicator variable that states whether the algorithm should use mini-batch updates.
clusterdiagnosticsList of the cluster diagnostic results for the SickleJr object. Includes diagnostic plots from fviz_nbclust and
and diagnostics from clValid
clustersList of results of different clustering methods performed on the SickleJr object
metadataList of metadata
lossVector of the value for the loss function
umapList of different UMAP-based dimension reductions using umap
plotsHolds various ggplot results for easy access of diagnostics and cluster visualizations