To ensure sufficient convergence of the loss for jrSiCKLSNMF with mini-batch updates, we
plot the loss vs the number of iterations for the mini-batch algorithm.
After a certain number of iterations, the loss should appear to oscillate
around a value. Before continuing with downstream analyses, please ensure that
the loss exhibits this sort of behavior. For the mini-batch algorithm, it is not
possible to use the convergence criteria used for the batch version of the
algorithm.