Wrapper function to run jrSiCKLSNMF on an object of class SickleJr. Performs jrSiCKLSNMF on the given SickleJr
RunjrSiCKLSNMF(
SickleJr,
rounds = 30000,
differr = 1e-06,
display_progress = TRUE,
lossonsubset = FALSE,
losssubsetsize = dim(SickleJr@H)[1],
minibatch = FALSE,
batchsize = 1000,
random_W_updates = FALSE,
seed = NULL,
minrounds = 200,
suppress_warnings = FALSE,
subsample = 1:dim(SickleJr@normalized.count.matrices[[1]])[2]
)An object of class SickleJr with updated \(\mathbf{W}^v\) matrices, updated \(\mathbf{H}\) matrix, and a vector of values for
the loss function added to the Wlist, H, and loss slots, respectively
An object of class SickleJr
Number of rounds: defaults to 2000
Tolerance for percentage change in loss between updates: defaults to 1e-6
Boolean indicating whether to display the progress bar for jrSiCKLSNMF
Boolean indicating whether to use a subset to calculate the loss function rather than the whole dataset
Size of the subset of data on which to calculate the loss
Boolean indicating whether to use mini-batch updates
Size of batch for mini-batch updates
Boolean indicating whether or not to use random_W_updates updates (i.e. only update \(\mathbf{W}^v\) once per mini-batch epoch)
Number specifying desired random seed
Minimum number of rounds: most helpful for the mini-batch algorithm
Boolean indicating whether to suppress warnings
A numeric used primarily when finding an appropriate number of latent factors: defaults to total number of cells
Cai2008jrSiCKLSNMF
jnmf2009jrSiCKLSNMF
Eddelbuettel2011jrSiCKLSNMF
Eddelbuettel2014jrSiCKLSNMF
Elyanow2020jrSiCKLSNMF
halfbakednmfjrSiCKLSNMF
Lee1999jrSiCKLSNMF
Liu2013jrSiCKLSNMF
SimSickleJrSmall<-RunjrSiCKLSNMF(SimSickleJrSmall,rounds=5)
Run the code above in your browser using DataLab